@@ -1,4 +1,4 @@
-from typing import List, Tuple
+from typing import List, Tuple, Generator
 
 from gcp_pilot import exceptions
 from gcp_pilot.base import AccountManagerMixin, GoogleCloudPilotAPI, PolicyType, DiscoveryMixin, ResourceType
@@ -210,9 +210,15 @@ class ServiceAgent:
         'Transcoder Service Account': ('gcp-sa-transcoder.iam.gserviceaccount.com', None)
     }
 
+    _suffixes = ['Service Agent', 'Agent', 'Service Account']
+
     @classmethod
-    def get_available_agents(cls) -> List[str]:
-        return list(cls.agents.keys())
+    def get_available_agents(cls) -> Generator[str, None, None]:
+        for agent in cls.agents:
+            name = agent
+            for suffix in cls._suffixes:
+                name = name.replace(suffix, '')
+            yield name
 
     @classmethod
     def _load_from_tsv(cls, filepath: str):
@@ -229,15 +235,20 @@ class ServiceAgent:
 
     @classmethod
     def _find(cls, service_name: str) -> Tuple[str, str]:
-        try:
-            return cls.agents[service_name]
-        except KeyError as e:
-            raise exceptions.NotFound(f"Service {service_name} not found") from e
+        candidates = [f'{service_name} {suffix}' for suffix in cls._suffixes]
+
+        for candidate in candidates:
+            try:
+                return cls.agents[candidate]
+            except KeyError:
+                continue
+
+        raise exceptions.NotFound(f"Service {service_name} not found")
 
     @classmethod
     def get_email(cls, service_name: str, project_id: str) -> str:
         domain, _ = cls._find(service_name=service_name)
-        project_number = cls._get_project_number(project_id=project_id)
+        project_number = cls.get_project_number(project_id=project_id)
         return f'service-{project_number}@{domain}'
 
     @classmethod
@@ -246,7 +257,8 @@ class ServiceAgent:
         return role
 
     @classmethod
-    def _get_project_number(cls, project_id: str) -> int:
+    def get_project_number(cls, project_id: str) -> int:
+        # TODO: cache this
         project = ResourceManager().get_project(project_id=project_id)
         return project['projectNumber']
 
@@ -263,10 +275,18 @@ class ServiceAgent:
                 except exceptions.ValidationError:
                     print(f'[X] {service_name}')
 
-    def get_compute_service_account(self, project_id: str) -> str:
-        project_number = self._get_project_number(project_id=project_id)
+    @classmethod
+    def get_compute_service_account(cls, project_id: str) -> str:
+        project_number = cls.get_project_number(project_id=project_id)
         return f'{project_number}-compute@developer.gserviceaccount.com'
 
-    def get_cloud_build_service_account(self, project_id: str = None) -> str:
-        project_number = self._get_project_number(project_id=project_id)
+    @classmethod
+    def get_cloud_build_service_account(cls, project_id: str = None) -> str:
+        project_number = cls.get_project_number(project_id=project_id)
         return f'{project_number}@cloudbuild.gserviceaccount.com'
+
+
+__all__ = (
+    'ResourceManager',
+    'ServiceAgent',
+)
